@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtinfo.c,v 1.18 2010/09/28 20:23:03 remko Exp $
+ *	$Id: gmtinfo.c,v 1.20 2011/03/05 21:24:29 guru Exp $
  *
- *    Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -30,7 +30,7 @@ int main (int argc, char **argv)
 	struct GMTMGG_REC record;
 	struct GMTMGG_TIME *gmt;
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	gmtmggpath_init();
 	
