@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt2kml.c,v 1.32 2010/08/22 07:36:48 guru Exp $
+ *	$Id: gmt2kml.c,v 1.35 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 2009-2010 by P. Wessel
+ *	Copyright (c) 2009-2011 by P. Wessel
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -511,7 +511,7 @@ int main (int argc, char **argv)
 	if (add_description) {
 		char line[BUFSIZ];
 		printf ("\t<description>\n\t\t<![CDATA[\n");
-		while (fgets (line, BUFSIZ, fp_h)) printf ("\t\t\t%s", line);
+		while (GMT_fgets (line, BUFSIZ, fp_h)) printf ("\t\t\t%s", line);
 		GMT_fclose (fp_h);
 		printf ("\t\t]]>\n\t</description>\n");
 	}
@@ -535,7 +535,7 @@ int main (int argc, char **argv)
 
 		if (!nofile && gmtdefs.verbose) fprintf (stderr, "%s: Working on file %s\n", GMT_program, argv[fno]);
 		if (get_label) {	/* Special ascii table processing */
-			while (fgets (buffer, BUFSIZ, fp)) {
+			while (GMT_fgets (buffer, BUFSIZ, fp)) {
 				if (buffer[0] == '#') continue;
 				switch (n_coord) {
 					case 2:	/* Just lon, lat, label */
